@@ -17,13 +17,12 @@ class AdjacencyConfusion:
                 if truthAdj and not estAdj:
                     self.__adjFn = self.__adjFn + 1
                 elif estAdj and not truthAdj:
-                    self.__adjFp = self.__adjTp + 1
+                    self.__adjFp = self.__adjFp + 1
                 elif estAdj and truthAdj:
                     self.__adjTp = self.__adjTp + 1
                 elif not estAdj and not truthAdj:
-                    self.__adjFn = self.__adjFn + 1
-        allEdges = truth.get_num_nodes() * (truth.get_num_nodes() - 1) / 2
-        self.__adjTn = allEdges - self.__adjFn
+                    self.__adjTn = self.__adjTn + 1
+
 
     def get_adj_tp(self):
         return self.__adjTp
